import * as fs from "node:fs";
import * as path from "node:path";
import { saveFile, getFiles, exportPDF } from "./files.js";
import { parseFile } from "./parse.js";
import { getDate, processGenerations } from "./process.js";
import { renderTable, renderTemplate } from "./render.js";

const query = process.argv.length > 2 ? process.argv[2].toLowerCase() : null;

const getTreeFilenames = async (dataDirectoryPath, query) => {
  const files = await getFiles(dataDirectoryPath);
  return files.filter((filename) => !query || filename.includes(query));
};

const treeFilenames = await getTreeFilenames("data/", query);

for (const filename of treeFilenames) {
  const basename = path.basename(filename).replace(".tree", "");
  const htmlFilename = `html/${basename}.html`;
  const pdfFilename = `pdf/${basename}.pdf`;

  const data = parseFile(filename);
  const { rows, numGenerations } = processGenerations(data);
  const { table, bodyClass } = renderTable(rows, numGenerations);

  const title = basename;
  const date = getDate();

  const outputData = renderTemplate({ title, date, table, bodyClass });

  saveFile(htmlFilename, outputData);

  exportPDF(`http://localhost/tabular-pedigrees/html/${htmlFilename}`, pdfFilename);

  console.log(pdfFilename);
}
