import { loadFile } from "./files.js";

const parseTree = (data, filename) => {
  let generations = {};

  for (const line of data.split("\n")) {
    if (line === "") continue;

    // Get number of hyphens
    const trimmedLine = line.replace(/^-+/, "");
    const genNumber = line.length - trimmedLine.length;
    const genKey = String(genNumber);

    const parts = trimmedLine.trim().split("|");
    let [name, birth, death, place] = parts.map((part) => (part ?? "").trim());

    let unsourced = false;
    if (name.endsWith(" [?]")) {
      name = name.replace(" [?]", "");
      unsourced = true;
    }

    if (!Object.keys(generations).includes(genKey)) {
      generations[genKey] = [];
    }

    generations[genKey].push({
      name,
      birth: birth === "?" ? "" : birth,
      death: death === "?" ? "" : death,
      place,
      unsourced,
    });
  }

  return {
    filename,
    generations,
  };
};

export const parseFile = (filename) => {
  const data = loadFile(filename);
  return parseTree(data, filename);
};
