import { loadFile } from "./files.js";

const renderLifeSpan = (cell) =>
  cell.birth || cell.death
    ? [cell.birth ?? "", cell.death ?? ""].join("&ndash;")
    : null;

const renderInfo = (cell) =>
  cell.birth || cell.death || cell.place
    ? `<span class="sub">${[renderLifeSpan(cell), cell.place]
        .filter((p) => p)
        .join(" in ")}</span>`
    : "";

const renderPerson = (cell) => `<span>${cell.name} ${renderInfo(cell)}</span>`;

const renderCell = (cell, row) =>
  `<td width="${row.width}%" colspan="${row.colSpan}" ${
    cell.unsourced ? ' class="unsourced"' : ""
  }>${renderPerson(cell)}</td>`;

const renderCells = (cells, row) =>
  row.cells.map((cell) => renderCell(cell, row));

const renderRow = (row) =>
  `<tr class="${row.classes.join(" ")}">${renderCells(row.cells, row).join(
    "\n"
  )}</tr>`;

export const renderTable = (rows, numGenerations) => ({
  table: rows.map(renderRow).join("\n"),
  bodyClass: `gens-${numGenerations}`,
});

export const renderTemplate = ({ bodyClass, title, date, table }) => {
  const template = loadFile("template/index.html");

  return template
    .replace("{{ title }}", title)
    .replace("{{ date }}", date)
    .replace("{{ table }}", table)
    .replace("{{ bodyClass }}", bodyClass);
};
